@@ -151,12 +151,15 @@ def generate_shell(mod_name, version, funcs):
 class Shell(object):
     ''' Generate a shell from functions '''
     
-    def __init__(self, name='Shell', version='1'):
+    def __init__(self, name='Shell', version='1', delimiter=',',
+        quotechar='"'):
         self.name = name
         self.version = version
         self.funcs = {}
         self.shell_class = None
         self.shell = None
+        self.default_delimiter = delimiter
+        self.default_quotechar = quotechar
 
     def cmd(self, *args, **kwargs):
         ''' Save shell command to self.funcs
@@ -169,8 +172,8 @@ class Shell(object):
             funcname = args[0]                                                  
         else:                                                                   
             funcname = kwargs.get('name')
-        delimiter = kwargs.get('delimiter', ',')
-        quotechar = kwargs.get('quotechar', '"')
+        delimiter = kwargs.get('delimiter', self.default_delimiter)
+        quotechar = kwargs.get('quotechar', self.default_quotechar)
         json_type = kwargs.get('json', False)
         def cmd_func(func):
             name = funcname or func.func_name
